summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-21 10:18:52 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-21 10:18:52 -0500
commit9dd40ae1aa6cb1226d6286810599b1fcd5052fa6 (patch)
tree7c39b561a95d9bd07d33ea63c2b7994ee0ddb261
parent78b78328521ffbb3d17b4d8a913621250f9da1ce (diff)
downloadlibpng-9dd40ae1aa6cb1226d6286810599b1fcd5052fa6.tar.gz
[pngcrush] Update bundled libpng to version 1.6.13v1.7.77
-rw-r--r--png.c14
-rw-r--r--png.h24
-rw-r--r--pngconf.h2
-rw-r--r--pngcrush.c5
-rw-r--r--pngcrush.h2
-rw-r--r--pngerror.c12
-rw-r--r--pnglibconf.h7
-rw-r--r--pngpriv.h8
-rw-r--r--pngread.c14
-rw-r--r--pngrutil.c8
10 files changed, 52 insertions, 44 deletions
diff --git a/png.c b/png.c
index f813e0a22..8d8841fd9 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_12 Your_png_h_is_not_version_1_6_12;
+typedef png_libpng_version_1_6_13 Your_png_h_is_not_version_1_6_13;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -773,13 +773,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.12 - June 12, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.6.13 - August 21, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.12 - June 12, 2014\
+ return "libpng version 1.6.13 - August 21, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
@@ -2293,8 +2293,8 @@ png_compare_ICC_profile_with_sRGB(png_const_structrp png_ptr,
*/
else if (!png_sRGB_checks[i].have_md5)
{
- png_chunk_report(png_ptr,
- "out-of-date sRGB profile with no signature",
+ png_chunk_report(png_ptr, "out-of-date sRGB profile with"
+ " no signature",
PNG_CHUNK_WARNING);
}
@@ -2307,8 +2307,8 @@ png_compare_ICC_profile_with_sRGB(png_const_structrp png_ptr,
* way. This probably indicates a data error or uninformed hacking.
* Fall through to "no match".
*/
- png_chunk_report(png_ptr,
- "Not recognizing known sRGB profile that has been edited",
+ png_chunk_report(png_ptr, "Not recognizing known sRGB profile that"
+ " has been edited",
PNG_CHUNK_WARNING);
break;
# endif
diff --git a/pngconf.h b/pngconf.h
index 1fb9c9e32..b60e919c9 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.12 - June 12, 2014
+ * libpng version 1.6.13 - August 21, 2014
*
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngcrush.c b/pngcrush.c
index b2e50795d..441ef6967 100644
--- a/pngcrush.c
+++ b/pngcrush.c
@@ -80,7 +80,7 @@
*
*/
-#define PNGCRUSH_VERSION "1.7.76"
+#define PNGCRUSH_VERSION "1.7.77"
/* Experimental: define these if you wish, but, good luck.
#define PNGCRUSH_COUNT_COLORS
@@ -308,6 +308,9 @@
Change log:
+Version 1.7.77 (built with libpng-1.6.13 and zlib-1.2.8)
+ Updated libpng to version 1.6.13.
+
Version 1.7.76 (built with libpng-1.6.12 and zlib-1.2.8)
Updated libpng to version 1.6.12.
diff --git a/pngcrush.h b/pngcrush.h
index d7238e5bd..efd2ae8cb 100644
--- a/pngcrush.h
+++ b/pngcrush.h
@@ -5,7 +5,7 @@
* license (see LICENSE, in pngcrush.c).
*/
-/* Special defines for pngcrush version 1.7.76 */
+/* Special defines for pngcrush version 1.7.77 */
#ifndef PNGCRUSH_H
#define PNGCRUSH_H
diff --git a/pngerror.c b/pngerror.c
index 03dcd7c2f..a2f8a563d 100644
--- a/pngerror.c
+++ b/pngerror.c
@@ -1,7 +1,7 @@
/* pngerror.c - stub functions for i/o and memory allocation
*
- * Last changed in libpng 1.6.11 [June 5, 2014]
+ * Last changed in libpng 1.6.13 [August 21, 2014]
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -415,10 +415,13 @@ png_app_error(png_const_structrp png_ptr, png_const_charp error_message)
}
#endif /* BENIGN_ERRORS */
+#define PNG_MAX_ERROR_TEXT 196 /* Currently limited by profile_error in png.c */
+#if defined(PNG_WARNINGS_SUPPORTED) || \
+ (defined(PNG_READ_SUPPORTED) && defined(PNG_ERROR_TEXT_SUPPORTED))
/* These utilities are used internally to build an error message that relates
* to the current chunk. The chunk name comes from png_ptr->chunk_name,
- * this is used to prefix the message. The message is limited in length
- * to 63 bytes, the name characters are output as hex digits wrapped in []
+ * which is used to prefix the message. The message is limited in length
+ * to 63 bytes. The name characters are output as hex digits wrapped in []
* if the character is invalid.
*/
#define isnonalpha(c) ((c) < 65 || (c) > 122 || ((c) > 90 && (c) < 97))
@@ -427,9 +430,6 @@ static PNG_CONST char png_digit[16] = {
'A', 'B', 'C', 'D', 'E', 'F'
};
-#define PNG_MAX_ERROR_TEXT 196 /* Currently limited be profile_error in png.c */
-#if defined(PNG_WARNINGS_SUPPORTED) || \
- (defined(PNG_READ_SUPPORTED) && defined(PNG_ERROR_TEXT_SUPPORTED))
static void /* PRIVATE */
png_format_buffer(png_const_structrp png_ptr, png_charp buffer, png_const_charp
error_message)
diff --git a/pnglibconf.h b/pnglibconf.h
index 9d4ef5a16..4c8605a8a 100644
--- a/pnglibconf.h
+++ b/pnglibconf.h
@@ -1,10 +1,10 @@
-/* libpng 1.6.10 STANDARD API DEFINITION */
+/* libpng 1.6.13 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.10 - March 6, 2014 */
+/* Libpng version 1.6.13 - August 21, 2014 */
-/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
+/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
/* This code is released under the libpng license. */
/* For conditions of distribution and use, see the disclaimer */
@@ -187,7 +187,6 @@
/* end of options */
/* settings */
#define PNG_API_RULE 0
-#define PNG_CALLOC_SUPPORTED
#define PNG_COST_SHIFT 3
#define PNG_DEFAULT_READ_MACROS 1
#define PNG_GAMMA_THRESHOLD_FIXED 5000
diff --git a/pngpriv.h b/pngpriv.h
index c4983137c..71a5ab456 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -119,8 +119,12 @@
* PNG_ARM_NEON_OPT is set in CPPFLAGS (to >0) then arm/arm_init.c will fail
* to compile with an appropriate #error if ALIGNED_MEMORY has been turned
* off.
+ *
+ * Note that gcc-4.9 defines __ARM_NEON instead of __ARM_NEON__, so we
+ * check both variants.
*/
-# if defined(__ARM_NEON__) && defined(PNG_ALIGNED_MEMORY_SUPPORTED)
+# if (defined(__ARM_NEON__) || defined(__ARM_NEON)) && \
+ defined(PNG_ALIGNED_MEMORY_SUPPORTED)
# define PNG_ARM_NEON_OPT 2
# else
# define PNG_ARM_NEON_OPT 0
@@ -148,7 +152,7 @@
* libpng implementation list for incorporation in the next minor release.
*/
# ifndef PNG_ARM_NEON_IMPLEMENTATION
-# ifdef __ARM_NEON__
+# if defined(__ARM_NEON__) || defined(__ARM_NEON)
# if defined(__clang__)
/* At present it is unknown by the libpng developers which versions
* of clang support the intrinsics, however some or perhaps all
diff --git a/pngread.c b/pngread.c
index 356ac76a4..845ff7b15 100644
--- a/pngread.c
+++ b/pngread.c
@@ -945,7 +945,7 @@ png_read_destroy(png_structrp png_ptr)
png_free(png_ptr, png_ptr->save_buffer);
#endif
-#if defined(PNG_STORE_UNKNOWN_CHUNKS_SUPPORTED) &&\
+#if defined(PNG_STORE_UNKNOWN_CHUNKS_SUPPORTED) && \
defined(PNG_READ_UNKNOWN_CHUNKS_SUPPORTED)
png_free(png_ptr, png_ptr->unknown_chunk.data);
#endif
@@ -1220,7 +1220,7 @@ png_read_png(png_structrp png_ptr, png_inforp info_ptr,
# define P_LINEAR8 4 /* 8-bit linear: only from a file value */
/* Color-map processing: after libpng has run on the PNG image further
- * processing may be needed to conver the data to color-map indicies.
+ * processing may be needed to convert the data to color-map indices.
*/
#define PNG_CMAP_NONE 0
#define PNG_CMAP_GA 1 /* Process GA data to a color-map with alpha */
@@ -2187,7 +2187,7 @@ png_image_read_colormap(png_voidp argument)
data_encoding = P_FILE;
/* The rows from libpng, while technically gray values, are now also
- * color-map indicies; however, they may need to be expanded to 1
+ * color-map indices; however, they may need to be expanded to 1
* byte per pixel. This is what png_set_packing does (i.e., it
* unpacks the bit values into bytes.)
*/
@@ -2273,8 +2273,8 @@ png_image_read_colormap(png_voidp argument)
* 8-bit GA and it has to be processing to single byte color-map
* values. Entry 254 is replaced by either a completely
* transparent entry or by the background color at full
- * precision (and the background color is not a simple gray leve
- * in this case.)
+ * precision (and the background color is not a simple gray
+ * level in this case.)
*/
expand_tRNS = 1;
output_processing = PNG_CMAP_TRANS;
@@ -2752,7 +2752,7 @@ png_image_read_colormap(png_voidp argument)
num_trans = 0;
output_processing = PNG_CMAP_NONE;
- data_encoding = P_FILE; /* Don't change from color-map indicies */
+ data_encoding = P_FILE; /* Don't change from color-map indices */
cmap_entries = png_ptr->num_palette;
if (cmap_entries > 256)
cmap_entries = 256;
@@ -2792,7 +2792,7 @@ png_image_read_colormap(png_voidp argument)
i < num_trans ? trans[i] : 255U, P_FILE/*8-bit*/);
}
- /* The PNG data may have indicies packed in fewer than 8 bits, it
+ /* The PNG data may have indices packed in fewer than 8 bits, it
* must be expanded if so.
*/
if (png_ptr->bit_depth < 8)
diff --git a/pngrutil.c b/pngrutil.c
index fd7af3850..3f415bf7d 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1319,9 +1319,9 @@ png_handle_iCCP(png_structrp png_ptr, png_inforp info_ptr, png_uint_32 length)
* chunk is just ignored, so does not invalidate the color space. An
* alternative is to set the 'invalid' flags at the start of this routine
* and only clear them in they were not set before and all the tests pass.
- * The minimum 'deflate' stream is assumed to be just the 2 byte header and 4
- * byte checksum. The keyword must be one character and there is a
- * terminator (0) byte and the compression method.
+ * The minimum 'deflate' stream is assumed to be just the 2 byte header and
+ * 4 byte checksum. The keyword must be at least one character and there is
+ * a terminator (0) byte and the compression method.
*/
if (length < 9)
{
@@ -2640,7 +2640,7 @@ png_handle_iTXt(png_structrp png_ptr, png_inforp info_ptr, png_uint_32 length)
/* prefix_length should now be at the trailing '\0' of the translated
* keyword, but it may already be over the end. None of this arithmetic
* can overflow because chunks are at most 2^31 bytes long, but on 16-bit
- * systems the available allocaton may overflow.
+ * systems the available allocation may overflow.
*/
++prefix_length;
diff --git a/png.h b/png.h
index 0659ad768..0071c1686 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.12 - June 12, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.12 - June 12, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -200,7 +200,9 @@
* 1.6.11 16 10611 16.so.16.11[.0]
* 1.6.12rc01-03 16 10612 16.so.16.12[.0]
* 1.6.12 16 10612 16.so.16.12[.0]
- * 1.6.13beta01 16 10613 16.so.16.13[.0]
+ * 1.6.13beta01-04 16 10613 16.so.16.13[.0]
+ * 1.6.13rc01-02 16 10613 16.so.16.13[.0]
+ * 1.6.13 16 10613 16.so.16.13[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -232,7 +234,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.12, June 12, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -344,13 +346,13 @@
* Y2K compliance in libpng:
* =========================
*
- * June 12, 2014
+ * August 21, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.12 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -412,9 +414,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.12"
+#define PNG_LIBPNG_VER_STRING "1.6.13"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.12 - June 12, 2014\n"
+ " libpng version 1.6.13 - August 21, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -422,7 +424,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 6
-#define PNG_LIBPNG_VER_RELEASE 12
+#define PNG_LIBPNG_VER_RELEASE 13
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
@@ -453,7 +455,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10612 /* 1.6.12 */
+#define PNG_LIBPNG_VER 10613 /* 1.6.13 */
/* Library configuration: these options cannot be changed after
* the library has been built.
@@ -558,7 +560,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_12;
+typedef char* png_libpng_version_1_6_13;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.12 - June 12, 2014
+ * libpng version 1.6.13 - August 21, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.12 - June 12, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.13 - August 21, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -232,7 +234,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.12, June 12, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.13, August 21, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -344,13 +346,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.12 are Y2K compliant. It is my belief that
+ * upward through 1.6.13 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*